@@ -106,6 +106,7 @@ static const CoderMapInfo
     { "CANVAS", "XC" },
     { "CMYKA", "CMYK" },
     { "CR2", "DNG" },
+    { "CR3", "DNG" },
     { "CRW", "DNG" },
     { "CUR", "ICON" },
     { "DATA", "INLINE" },
@@ -268,9 +269,13 @@ static SplayTreeInfo
   Forward declarations.
 */
 static MagickBooleanType
-  IsCoderTreeInstantiated(ExceptionInfo *),
+  IsCoderTreeInstantiated(ExceptionInfo *);
+
+#if !MAGICKCORE_ZERO_CONFIGURATION_SUPPORT
+static MagickBooleanType
   LoadCoderCache(SplayTreeInfo *,const char *,const char *,const size_t,
     ExceptionInfo *);
+#endif
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -337,7 +342,7 @@ static SplayTreeInfo *AcquireCoderCache(const char *filename,
   if (cache == (SplayTreeInfo *) NULL)
     ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
   status=MagickTrue;
-#if !defined(MAGICKCORE_ZERO_CONFIGURATION_SUPPORT)
+#if !MAGICKCORE_ZERO_CONFIGURATION_SUPPORT
   {
     const StringInfo
       *option;
@@ -763,6 +768,7 @@ MagickExport MagickBooleanType ListCoderInfo(FILE *file,
   return(MagickTrue);
 }
 
+#if !MAGICKCORE_ZERO_CONFIGURATION_SUPPORT
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -965,3 +971,4 @@ static MagickBooleanType LoadCoderCache(SplayTreeInfo *cache,const char *xml,
   token=(char *) RelinquishMagickMemory(token);
   return(status != 0 ? MagickTrue : MagickFalse);
 }
+#endif
