@@ -732,8 +732,7 @@ MagickExport char *ConstantString(const char *source)
 %  out exceeding the given pre-declared length.
 %
 %  The destination buffer is always null-terminated even if the string must be
-%  truncated.  The return value is the minimum of the source string length or
-%  the length parameter.
+%  truncated.  The return value is length of the string.
 %
 %  The format of the CopyMagickString method is:
 %
@@ -765,34 +764,23 @@ MagickExport size_t CopyMagickString(char *magick_restrict destination,
   q=destination;
   for (n=length; n > 4; n-=4)
   {
-    *q=(*p++);
-    if (*q == '\0')
+    if (((*q++)=(*p++)) == '\0')
       return((size_t) (p-source-1));
-    q++;
-    *q=(*p++);
-    if (*q == '\0')
+    if (((*q++)=(*p++)) == '\0')
       return((size_t) (p-source-1));
-    q++;
-    *q=(*p++);
-    if (*q == '\0')
+    if (((*q++)=(*p++)) == '\0')
       return((size_t) (p-source-1));
-    q++;
-    *q=(*p++);
-    if (*q == '\0')
+    if (((*q++)=(*p++)) == '\0')
       return((size_t) (p-source-1));
-    q++;
   }
-  if (n != 0)
-    for (n--; n != 0; n--)
-    {
-      *q=(*p++);
-      if (*q == '\0')
-        return((size_t) (p-source-1));
-      q++;
-    }
   if (length != 0)
-    *q='\0';
-  return((size_t) (p-source-1));
+    {
+      while (--n != 0)
+        if (((*q++)=(*p++)) == '\0')
+          return((size_t) (p-source-1));
+      *q='\0';
+    }
+  return((size_t) (p-source));
 }
 
 /*
@@ -2603,9 +2591,7 @@ MagickExport MagickBooleanType SubstituteString(char **string,
       (void) memmove(p+replace_extent,p+search_extent,
         strlen(p+search_extent)+1);
     (void) memcpy(p,replace,replace_extent);
-    p+=replace_extent;
-    if (replace_extent != 0)
-      p--;
+    p+=replace_extent-1;
   }
   return(status);
 }
